(* $Id: menu_main.ml 678 2007-02-25 17:16:54Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2003 by Gerd Stolpmann. 
 * 
 * This file is part of godi-tools. 
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)


let help_str =
  "The GODI console allows you to build O'Caml libraries and applications\n" ^
  "from source, to install them, and to manage the installation.\n" ^ 
  "\n" ^
  "You can activate functions of the GODI console in two ways: Many functions\n" ^
  "are bound to letter keys, and by pressing the key the function is called.\n" ^
  "The foot line at the bottom of the page shows which of these functions are\n" ^ 
  "available. For example, the letter 'x' often exits the current menu. The\n" ^
  "other way to invoke functions is to enter a number, and to press the RETURN\n" ^ 
  "key. You can find the defined numbers in the main text, surrounded by \n" ^ 
  "brackets.\n" ^
  "\n" ^
  "The 'p' and 'n' keys (and on many keyboards the cursor keys, too) scroll\n" ^
  "the current view up and down.\n" ^
  "\n" ^ 
  "GODI is a build framework, i.e. it provides an environment into which\n" ^
  "O'Caml libraries and applications can be integrated. It does not include\n" ^
  "the source code of these components, but it knows where to download them, and\n" ^
  "how to configure, build, and install them. There is a central GODI server\n" ^
  "where this knowledge is maintained, and from where the knowledge of the\n" ^
  "available software can be updated (function [1] in the main menu). We\n" ^
  "call this knowledge also the 'build instructions'.\n" ^ 
  "\n" ^
  "Before software is installed, it must be selected. To do so, enter function\n" ^ 
  "[2] of the main menu. This shows the list of software GODI knows about,\n" ^
  "and you can select and deselect software packages. You can also look\n" ^
  "into the description of the software.\n" ^
  "\n" ^ 
  "From the package list you can start the installation process. GODI\n" ^
  "already knows about dependencies between packages, and keeps the software\n" ^
  "in a consistent state.\n" ^
  "\n" ^ 
  "More help can be obtained in the individual menus."
;;


let display (pg : Miniui.page) =
  pg # clear();

  Menu_aux.add_full_head pg ">>> Main Menu <<<";

  Menu_aux.add_menu 
    ~lmargin:10
    pg
    [ `Left 3; `Delim "   " ] 
    [ `Item ( ["[1]"; "Update the list of available packages"],
	      1,
	      (fun _ -> 
		 Menu_update.display (pg # new_page()) ) );
      `Separator "";
      `Item ( ["[2]"; "Select source packages"],
	      2,
	      (fun _ -> 
		 Menu_select.display (pg # new_page())) );
      `Separator "";
      `Item ( ["[3]"; "Exit program"],
	      3,
	      (fun _ -> pg#quit()))
    ];

  ignore(pg # add_foot_button ~text:"help" ~underline:0
	   ~callback:(Menu_help.display pg#new_page help_str)
	   (`Keypress 'h'));

  pg # loop()
;;
